@@ -1,3 +1,4 @@
+from django.conf import settings
 from django.core.management.base import BaseCommand
 from django.core.management import call_command
 
@@ -8,5 +9,6 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         call_command('makemigrations', verbosity=3)
         call_command('migrate', verbosity=3)
-        call_command('addlang', verbosity=3)
+        # call_command('addlang', settings.LANGUAGE_CODE, verbosity=3)
         self.stdout.write('Success deploy min oms-cms')
+
